@@ -545,9 +545,9 @@ congresso_bib <- function(input_date,input_tam){
     formatobook <- "booktitle="
     localsocibook <- "location="
     organizacaobook <- "publisher="
-    anoorgbook <- "year"
+    anoorgbook <- "year="
     paginabook <- "pages="
-    descricaobook <- "note"
+    descricaobook <- "note="
     linkbook <- "url="
     acessobook <- "urldate="
     chave_entrada <- "{"
